@@ -31,6 +31,8 @@ QObject *VaultApplet::vaultsModel()
     return m_vaultsModel;
 }
 
-K_PLUGIN_CLASS_WITH_JSON(VaultApplet, "metadata.json")
+K_PLUGIN_CLASS(VaultApplet)
 
 #include "vaultapplet.moc"
+
+#include "moc_vaultapplet.cpp"
